@@ -24,13 +24,12 @@ def assemble(lines):
     current_address = 1
     for line in tokenized_lines:
         tokens, rest = line
-        for token in tokens:
-            token_type, value = token
-            if token_type == 'label':
-                labels[value] = current_address
+        token_type, value = tokens[0]
+        if token_type == 'label':
+            labels[value] = current_address
 
-            elif token_type == 'operator':
-                current_address += 1
+        elif token_type == 'operator':
+            current_address += 1
 
     #actual assemble pass
     assembly = []
@@ -75,9 +74,8 @@ def assemble(lines):
                             value.capitalize()](a, b, c)
 
                     # Two params
-                    elif instruction in ['call', 'jmp', 'ldi',
-                                         'sti', 'stg', 'cmp',
-                                         'mv', 'neg', 'not']:
+                    elif instruction in ['jmp', 'ldi', 'sti', 'stg',
+                                         'cmp', 'mv', 'neg', 'not']:
                         _, a = tokens.next()
                         maybe_label, b = tokens.next()
                         if maybe_label == 'label':
@@ -85,7 +83,7 @@ def assemble(lines):
                         instruction = instruction_map[value.capitalize()](a, b)
 
                     # One param
-                    elif instruction in ['ldg', 'setg', 'nop', 'ret']:
+                    elif instruction in ['ldg', 'setg', 'nop']:
                         _, a = tokens.next()
                         instruction = instruction_map[value.capitalize()](a)
 
@@ -93,6 +91,16 @@ def assemble(lines):
                     elif instruction in ['nop', 'ret']:
                         instruction = instruction_map[value.capitalize()]()
 
+                    # special cases
+                    elif instruction == 'call':
+                        maybe_label, a = tokens.next()
+                        if maybe_label == 'label':
+                            b = labels[a]
+                            a = 0
+                        else:
+                            _, b = tokens.next()
+                        instruction = instruction_map[value.capitalize()](a, b)
+
                     if instruction.cond == Cond.UNSET:
                         instruction.cond = condition
                     assembly.append(instruction)
